# GTree

[GTree](https://pypi.org/project/gtree/) provides a general tree implementation which is not really useful in itself (or is it?).

## Usefulness

Ignoring the statement above, it provides a method for building a tree from dictionaries and convinient methods for iterating trees (bottom up as well as top to bottom).

This means that you can define a tree structure in e.g. JSON or YAML files, load it and then build a tree.

See examples directory for more!

## Requirements

The `gtree` package has no requirements other than Python 3.
